import {
  select,csv,scaleLinear,scaleTime,extent,axisLeft,axisBottom,line,curveBasis
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');
const month_to_number=["January","February","March","April",
                       "May","June","July","August","September",
                       "October","November","December"]
//defining X-axis
const render = data => {
  const xValue = d => d.MonthI;
  const xAxisLabel = 'Month';
  //labeling band defining Y-axis
  
  const yValue = d => d.Max_AQI;
  const circleRadius = 2;
  const yAxisLabel = 'Max Ozone AQI';
  //styles of plot
  const margin = { top: 60, right: 40, bottom: 88, left: 105 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0,innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(15);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -70)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 50)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  //line graph genertor
  const lineGenerator = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue(d)))
 	  .curve(curveBasis);
  
  g.append('path')
      .attr('class', 'line-path')
      .attr('d', lineGenerator(data));
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};
//gist data is linked 
csv('https://gist.githubusercontent.com/sairam-kakarla/392d934e39b16d77d1abe6e9a3347224/raw/d50b3563dd0d42bbddf3d9fb66ddb2810710e695/month_ozone_max_aqi.csv')
  .then(data => {
    data.forEach(d => {
      d.Max_AQI = +d.Max_AQI;
      d.MonthI = month_to_number.indexOf(d.Month)+1;
      console.log(d); 
    }
               );
    render(data);
  });